pub struct SchemaConstraint {
pub id: u64,
pub name: String,
pub kind: SchemaConstraintKind,
}Expand description
Durable catalog identity for a SQL table constraint.
id and name are assigned once when the constraint is created and are
persisted with the schema. Renaming a table or column updates the bound
columns in kind, but deliberately does not rename the public constraint.
Fields
id: u64name: Stringkind: SchemaConstraintKindTrait Implementations
Sourceimpl Clone for SchemaConstraint
impl Clone for SchemaConstraint
Sourcefn clone(&self) -> SchemaConstraint
fn clone(&self) -> SchemaConstraint
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SchemaConstraint
impl Debug for SchemaConstraint
impl Eq for SchemaConstraint
Sourceimpl PartialEq for SchemaConstraint
impl PartialEq for SchemaConstraint
impl StructuralPartialEq for SchemaConstraint