pub struct I64Set { /* private fields */ }Expand description
High-performance HashSet for i64 keys.
Uses the same optimizations as I64Map:
- i64::MIN as the in-table empty sentinel with that logical value out of band
- FxHash with pre-mixing (XOR>>16 before multiply) - 0 sequential collisions
- Backward-shift deletion (no tombstones)
Supports the full i64 value domain.
Implementations
Sourceimpl I64Set
impl I64Set
pub fn new() -> Self
pub fn with_capacity(capacity: usize) -> Self
pub fn len(&self) -> usize
pub fn is_empty(&self) -> bool
pub fn capacity(&self) -> usize
Sourcepub fn reserve(&mut self, additional: usize)
pub fn reserve(&mut self, additional: usize)
Reserves capacity for at least additional more elements to be inserted
in the set. The collection may reserve more space to avoid frequent reallocations.
Sourcepub fn insert(&mut self, key: i64) -> bool
pub fn insert(&mut self, key: i64) -> bool
Insert a value into the set. Returns true if the value was newly inserted.
pub fn contains(&self, key: i64) -> bool
pub fn remove(&mut self, key: i64) -> bool
Sourcepub fn shrink_to_fit(&mut self)
pub fn shrink_to_fit(&mut self)
Shrink the set to fit its current contents, releasing excess memory.
Call this after removing many entries to reclaim memory.
pub fn clear(&mut self)
pub fn iter(&self) -> impl Iterator<Item = i64> + '_