Value type for RadixDB - runtime values with type information
This module provides a unified Value enum that represents SQL values with full type information and conversion capabilities.
Structs
- External
Value Ref - Borrowed view of the canonical payload carried by an external value.
Enums
- Value
- A runtime value with type information
Constants
- MAX_
DECIMAL_ PRECISION - MAX_
EXTERNAL_ VALUE_ BYTES - NULL_
VALUE - Static NULL value for zero-cost reuse
Functions
- format_
bytes_ hex - format_
date_ days_ since_ unix_ epoch - format_
decimal_ parts - format_
uuid_ bytes - Format raw 16-byte UUID storage as canonical lowercase hyphenated text.
- format_
vector_ bytes - Format packed LE f32 bytes as “[1.0, 2.0, 3.0]” string
- parse_
date_ days_ since_ unix_ epoch - parse_
decimal_ str - Parse a plain decimal string into exact wire-style decimal parts.
- parse_
timestamp - Parse a timestamp string with multiple format support
- parse_
uuid_ str - Parse a UUID string into raw 16-byte UUID storage.
- parse_
vector_ str - Parse a vector string in [f32, f32, …] format
- validate_
decimal_ shape - Validate the declared physical DECIMAL payload.